@@ -32,6 +32,7 @@ class Wire:
             if func:
                 # async function
                 if inspect.iscoroutinefunction(func):
+
                     response: typing.Union[Response, typing.Any] = await func(req, **params)
                     if not isinstance(response, Response):
                         if type(response) == str:
@@ -40,12 +41,12 @@ class Wire:
                             response = JsonResponse(response, 200)
                     await response(scope, receive, send)
                 # static files
-                if isinstance(func, StaticFiles):
+                elif isinstance(func, StaticFiles):
                     content, typ = func.provide(req.path)
                     resp = Response(content, headers={"content-type": typ})
                     await resp(scope, receive, send)
                  # sync function
-                else:
+                elif inspect.isfunction(func) and not inspect.iscoroutinefunction(func):
                     response: typing.Union[Response, typing.Any] = func(req, **params)
                     if not isinstance(response, Response):
                         if type(response) == str:
